@@ -1,6 +1,7 @@
 import asyncio
 from collections import defaultdict
 from gettext import gettext as _
+import hashlib
 import json
 import logging
 import tarfile
@@ -54,6 +55,7 @@ from pulp_ansible.app.models import (
     CollectionImport,
     CollectionRemote,
     CollectionVersion,
+    CollectionVersionSignature,
     Tag,
 )
 from pulp_ansible.app.serializers import CollectionVersionSerializer, CollectionRemoteSerializer
@@ -63,11 +65,83 @@ from pulp_ansible.app.tasks.utils import (
     parse_collections_requirements_file,
     RequirementsFileEntry,
 )
+from asgiref.sync import sync_to_async
+
+from django.db.utils import IntegrityError
+from galaxy_importer.collection import sync_collection
+from git import GitCommandError, Repo
+
+
+from uuid import uuid4
 
 
 log = logging.getLogger(__name__)
 
 
+async def declarative_content_from_git_repo(remote, url, git_ref=None, metadata_only=False):
+    """Returns a DeclarativeContent for the Collection in a Git repository."""
+    if git_ref:
+        try:
+            gitrepo = Repo.clone_from(url, uuid4(), depth=1, branch=git_ref)
+        except GitCommandError:
+            gitrepo = Repo.clone_from(url, uuid4())
+            gitrepo.git.checkout(git_ref)
+    else:
+        gitrepo = Repo.clone_from(url, uuid4(), depth=1)
+    commit_sha = gitrepo.head.commit.hexsha
+    metadata, artifact_path = sync_collection(gitrepo.working_dir, ".")
+    if not metadata_only:
+        artifact = Artifact.init_and_validate(artifact_path)
+        try:
+            await sync_to_async(artifact.save)()
+        except IntegrityError:
+            artifact = Artifact.objects.get(sha256=artifact.sha256)
+        metadata["artifact_url"] = reverse("artifacts-detail", args=[artifact.pk])
+        metadata["artifact"] = artifact
+    else:
+        metadata["artifact"] = None
+        metadata["artifact_url"] = None
+    metadata["remote_artifact_url"] = "{}/commit/{}".format(url.rstrip("/"), commit_sha)
+
+    artifact = metadata["artifact"]
+    try:
+        collection_version = await sync_to_async(create_collection_from_importer)(
+            metadata, metadata_only=metadata_only
+        )
+        await sync_to_async(ContentArtifact.objects.get_or_create)(
+            artifact=artifact,
+            content=collection_version,
+            relative_path=collection_version.relative_path,
+        )
+    except ValidationError as e:
+        if e.args[0]["non_field_errors"][0].code == "unique":
+            namespace = metadata["metadata"]["namespace"]
+            name = metadata["metadata"]["name"]
+            version = metadata["metadata"]["version"]
+        else:
+            raise e
+        collection_version = await sync_to_async(CollectionVersion.objects.get)(
+            namespace=namespace, name=name, version=version
+        )
+    if artifact is None:
+        artifact = Artifact()
+    d_artifact = DeclarativeArtifact(
+        artifact=artifact,
+        url=metadata["remote_artifact_url"],
+        relative_path=collection_version.relative_path,
+        remote=remote,
+        deferred_download=metadata_only,
+    )
+
+    # TODO: docs blob support??
+
+    d_content = DeclarativeContent(
+        content=collection_version,
+        d_artifacts=[d_artifact],
+    )
+    return d_content
+
+
 def update_collection_remote(remote_pk, *args, **kwargs):
     """
     Update a CollectionRemote.
@@ -412,6 +486,7 @@ class CollectionSyncFirstStage(Stage):
         self.collection_info = parse_collections_requirements_file(remote.requirements_file)
         self.exclude_info = {}
         self.add_dependents = self.collection_info and self.remote.sync_dependencies
+        self.signed_only = self.remote.signed_only
         self.already_synced = set()
         self._unpaginated_collection_metadata = None
         self._unpaginated_collection_version_metadata = None
@@ -493,6 +568,10 @@ class CollectionSyncFirstStage(Stage):
         self.already_synced.add(cv_unique)
 
         info = metadata["metadata"]
+        signatures = metadata.get("signatures")
+
+        if self.signed_only and not signatures:
+            return
 
         if self.add_dependents:
             dependencies = info["dependencies"]
@@ -514,7 +593,6 @@ class CollectionSyncFirstStage(Stage):
             setattr(collection_version, attr_name, attr_value)
 
         artifact = metadata["artifact"]
-
         d_artifact = DeclarativeArtifact(
             artifact=Artifact(sha256=artifact["sha256"], size=artifact["size"]),
             url=url,
@@ -535,6 +613,24 @@ class CollectionSyncFirstStage(Stage):
         await self.parsing_metadata_progress_bar.aincrement()
         await self.put(d_content)
 
+        if signatures:
+            collection_version = await d_content.resolution()
+            for signature in signatures:
+                sig = signature["signature"].encode("utf8")
+                cv_signature = CollectionVersionSignature(
+                    signed_collection=collection_version,
+                    data=sig,
+                    digest=hashlib.sha256(sig),
+                    pubkey_fingerprint=signature["pubkey_fingerprint"],
+                )
+                await self.put(DeclarativeContent(content=cv_signature))
+
+    async def _add_collection_version_from_git(self, url, gitref, metadata_only):
+        d_content = await declarative_content_from_git_repo(
+            self.remote, url, gitref, metadata_only=False
+        )
+        await self.put(d_content)
+
     def _collection_versions_list_downloader(
         self, api_version, collection_endpoint, namespace, name, page_num, page_size
     ):
@@ -610,17 +706,29 @@ class CollectionSyncFirstStage(Stage):
             await self.put(d_content)
 
         all_versions_of_collection = self._unpaginated_collection_version_metadata[namespace][name]
-
         for col_version_metadata in all_versions_of_collection:
             if col_version_metadata["version"] in requirement:
-                collection_version_url = urljoin(self.remote.url, f"{col_version_metadata['href']}")
-                tasks.append(
-                    loop.create_task(
-                        self._add_collection_version(
-                            self._api_version, collection_version_url, col_version_metadata
+                if "git_url" in col_version_metadata and col_version_metadata["git_url"]:
+                    tasks.append(
+                        loop.create_task(
+                            self._add_collection_version_from_git(
+                                col_version_metadata["git_url"],
+                                col_version_metadata["git_commit_sha"],
+                                False,
+                            )
+                        )
+                    )
+                else:
+                    collection_version_url = urljoin(
+                        self.remote.url, f"{col_version_metadata['href']}"
+                    )
+                    tasks.append(
+                        loop.create_task(
+                            self._add_collection_version(
+                                self._api_version, collection_version_url, col_version_metadata
+                            )
                         )
                     )
-                )
         await asyncio.gather(*tasks)
 
     async def _fetch_collection_metadata(self, requirements_entry):
@@ -938,7 +1046,10 @@ class CollectionContentSaver(ContentSaver):
                     )
                     if runtime_metadata:
                         runtime_yaml = yaml.safe_load(runtime_metadata)
-                        collection_version.requires_ansible = runtime_yaml.get("requires_ansible")
+                        if runtime_yaml:
+                            collection_version.requires_ansible = runtime_yaml.get(
+                                "requires_ansible"
+                            )
                     manifest_data = json.load(
                         get_file_obj_from_tarball(tar, "MANIFEST.json", artifact.file.name)
                     )
